@@ -3,11 +3,11 @@
  *  Module    : auth.c
  *  Author    : Dirk Nimmich <nimmich@muenster.de>
  *  Created   : 1997-04-05
- *  Updated   : 2016-12-13
+ *  Updated   : 2017-10-18
  *  Notes     : Routines to authenticate to a news server via NNTP.
  *              DON'T USE get_respcode() THROUGHOUT THIS CODE.
  *
- * Copyright (c) 1997-2017 Dirk Nimmich <nimmich@muenster.de>
+ * Copyright (c) 1997-2018 Dirk Nimmich <nimmich@muenster.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -297,12 +297,12 @@ authinfo_plain(
 				return TRUE;
 			}
 		}
-#   ifdef DEBUG
+#	ifdef DEBUG
 		else {
 			if (debug & DEBUG_NNTP)
 				 debug_print_file("NNTP", "read_newsauth_file(\"%s\", \"%s\", \"%s\") failed", server, authuser, authpass);
 		}
-#   endif /* DEBUG */
+#	endif /* DEBUG */
 	}
 
 	/*
@@ -351,7 +351,7 @@ authinfo_plain(
 			 * on some systems (i.e. Solaris) getpass(3) is limited
 			 * to 8 chars -> we use tin_getline()
 			 */
-			STRCPY(authpassword, tin_getline(_(txt_auth_pass), FALSE, NULL, sizeof(authpassword) - 1, TRUE, HIST_NONE));
+			STRCPY(authpassword, tin_getline(_(txt_auth_pass), 0, NULL, sizeof(authpassword) - 1, TRUE, HIST_NONE));
 #	endif /* USE_CURSES */
 
 #	ifdef USE_SASL
