@@ -3,11 +3,11 @@
  *  Module    : regex.c
  *  Author    : Jason Faultless <jason@altarstone.com>
  *  Created   : 1997-02-21
- *  Updated   : 2011-11-09
+ *  Updated   : 2017-02-17
  *  Notes     : Regular expression subroutines
  *  Credits   :
  *
- * Copyright (c) 1997-2017 Jason Faultless <jason@altarstone.com>
+ * Copyright (c) 1997-2018 Jason Faultless <jason@altarstone.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -110,7 +110,7 @@ compile_regex(
 	struct regex_cache *cache,
 	int options)
 {
-	const char *regex_errmsg = 0;
+	const char *regex_errmsg = NULL;
 	int regex_errpos, my_options = options;
 
 #if defined(MULTIBYTE_ABLE) && !defined(NO_LOCALE) && (defined(PCRE_MAJOR) && PCRE_MAJOR >= 4)
