@@ -3,10 +3,10 @@
  *  Module    : save.c
  *  Author    : I. Lea & R. Skrenta
  *  Created   : 1991-04-01
- *  Updated   : 2016-10-10
+ *  Updated   : 2017-08-21
  *  Notes     :
  *
- * Copyright (c) 1991-2017 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
+ * Copyright (c) 1991-2018 Iain Lea <iain@bricbrac.de>, Rich Skrenta <skrenta@pbm.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -493,7 +493,7 @@ save_and_process_art(
 		const char *partprefix;
 		char *ptr;
 		char archpath[PATH_LEN];
-		char filename[NAME_LEN];
+		char filename[NAME_LEN + 1];
 
 		/*
 		 * We need either a part or a patch number, part takes precedence
@@ -664,7 +664,7 @@ generate_savepath(
 	const char *name;
 	t_bool mbox;
 
-	savepath = my_malloc(PATH_LEN + 1);
+	savepath = my_malloc(PATH_LEN);
 	/*
 	 * Get the filename to save to in 'savepath'
 	 */
@@ -882,8 +882,6 @@ post_process_uud(
 	my_printf(_(txt_libuu_saved), count, num_save, errors, PLURAL(errors, txt_error));
 	my_printf(cCRLF);
 	UUCleanUp();
-
-	return;
 }
 
 #else
@@ -1143,7 +1141,6 @@ uudecode_line(
 			}
 		}
 	}
-	return;
 }
 
 
@@ -1173,7 +1170,7 @@ post_process_sh(
 		if ((fp_in = fopen(save[i].path, "r")) == NULL)
 			continue;
 
-		wait_message(1, _(txt_extracting_shar), save[i].path);
+		wait_message(0, _(txt_extracting_shar), save[i].path);
 
 		while (fgets(buf, (int) sizeof(buf), fp_in) != NULL) {
 			/* find #!/bin/sh style patterns */
@@ -1186,8 +1183,10 @@ post_process_sh(
 		}
 		fclose(fp_in);
 
-		if (fp_out == NULL)			/* Didn't extract any shar */
+		if (fp_out == NULL) {			/* Didn't extract any shar */
+			my_fputs(cCRLF, stdout);
 			continue;
+		}
 
 		fclose(fp_out);
 		fp_out = NULL;
@@ -1201,7 +1200,6 @@ post_process_sh(
 #endif /* !M_UNIX */
 		unlink(file_out);
 	}
-	return;
 }
 
 
@@ -2053,7 +2051,6 @@ tag_pattern(
 		FreeIfNeeded(cache.re);
 		FreeIfNeeded(cache.extra);
 	}
-	return;
 }
 
 
